[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/orgSailingVLM/pySailingVLM/main?labpath=pySailingVLM%2Fexamples) [![orgSailingVLM](https://circleci.com/gh/orgSailingVLM/pySailingVLM.svg?style=shield)](https://app.circleci.com/pipelines/github/orgSailingVLM/pySailingVLM)
# About package

Nowadays, the state-of-the-art CFD solvers (FEM, VOF, LBM) can provide incredibly accurate results for almost any geometry. However, the solution comes at the price of high amount of computational resources. To circumvent this issue, the low fidelity approaches like Vortex Lattice Method can be employed for particular types of computational problems. The VLM is an engineering standard in the conceptual design phase of aircraft or sailing yacht as it allows designers to quickly estimate the performance of numerous different models. Due to the specifics of conditions in which a sailing yacht operates, the VLM solvers dedicated to aircraft design can not be adopted in a straightforward fashion. Here, we present the first open-source Python package which implements the Vortex Lattice Method for the initial aerodynamic analysis of upwind sails. Through its lightweight requirements, the software can be easily installed and executed locally or accessed in a cloud environment such as Binder.


# Overview
## Jupyter & cli
pySailingVLm can be used as cli script or inside Jupyter Notebook. For more information see docs and interative Notebooks examples.
## Example outputs
pySailingVLM calculates forces, coefficients, moments acting on sails. Results are visualized and plotted:

[<img src="https://raw.githubusercontent.com/orgSailingVLM/vlmbook/main/figures/pysailingvlm_yacht.png" width="400"/>](pysailingvlm_yacht.png)

Users can also see colormap with their sails:

[<img src="https://raw.githubusercontent.com/orgSailingVLM/vlmbook/main/figures/rc44_conv.png" width="400"/>](cp.png)


Sample graphs generated by pySailingVLM:

[<img src="https://github.com/orgSailingVLM/vlmbook/blob/main/figures/sailing_vlm_cl_example.png?raw=true" width="400"/>](cl_example.png)

[<img src="https://github.com/orgSailingVLM/vlmbook/blob/main/figures/sailinig_cd_example.png?raw=true" width="400"/>](cd_example.png)


And 
# More information
Please follow [documentation](orgsailingvlm.github.io/vlmbook) for installation and usage.
